bayespy.inference.vmp.nodes.deterministic.Deterministic.__init__
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.__init__